@@ -43,7 +43,7 @@
 
 #include "driver.h"
 
-ConfigDriver::ConfigDriver() :
+PhonedevConfig::PhonedevConfig() :
 Keydata("/bayonne/phone")
 {
 	static KEYDEF defkeys[] = {
@@ -55,15 +55,15 @@ Keydata("/bayonne/phone")
 	Load(defkeys);
 }
 
-IVRDriver::IVRDriver() :
+PhonedevDriver::PhonedevDriver() :
 Driver()
 {
 	port_count = getDevices();
-	status = TrunkDriver::status;
-	memset(TrunkDriver::status, ' ', sizeof(TrunkDriver::status));
-	ports = new TrunkDriver *[port_count];
+	status = PhonedevTrunk::status;
+	memset(PhonedevTrunk::status, ' ', sizeof(PhonedevTrunk::status));
+	ports = new PhonedevTrunk *[port_count];
 	groups = new TrunkGroup *[port_count];
-	memset(ports, 0, sizeof(TrunkDriver *) * port_count);
+	memset(ports, 0, sizeof(PhonedevTrunk *) * port_count);
 	memset(groups, 0, sizeof(TrunkGroup *) * port_count);
 
 	thread_count = thread_select = 0;
@@ -71,14 +71,14 @@ Driver()
 	slog(SLOG_INFO) << "Generic Phone Device (phonedev) driver loaded; capacity=" << port_count << endl;
 }
 
-IVRDriver::~IVRDriver()
+PhonedevDriver::~PhonedevDriver()
 {
 	Stop();
 	delete ports;
 	delete groups;
 }
 
-int IVRDriver::Start(void)
+int PhonedevDriver::Start(void)
 {
 	char path[32];
 	int fd, ts;
@@ -92,7 +92,7 @@ int IVRDriver::Start(void)
 	}
 
 	slog(SLOG_INFO) << "driver starting " << scount << " service thread(s)" << endl;
-	threads = new ServiceDriver[scount];
+	threads = new PhonedevService[scount];
 
 	for(ts = 0; ts < port_count; ++ts)
 	{
@@ -102,7 +102,7 @@ int IVRDriver::Start(void)
 			continue;
 		if(!getuid())
 			fchown(fd, keyserver.getUid(), keyserver.getGid());
-		ports[ts] = new TrunkDriver(fd, ts);
+		ports[ts] = new PhonedevTrunk(fd, ts);
 		++count;
 	}
 
@@ -110,7 +110,7 @@ int IVRDriver::Start(void)
 	return count;
 }
 
-void IVRDriver::Stop(void)
+void PhonedevDriver::Stop(void)
 {
 	int id;
 	if(!active)
@@ -124,14 +124,14 @@ void IVRDriver::Stop(void)
 				delete ports[id];
 		}
 	}
-	memset(ports, 0, sizeof(TrunkDriver *) * port_count);
+	memset(ports, 0, sizeof(PhonedevTrunk *) * port_count);
 	delete[] threads;
 	
 	active = false;
 	slog(SLOG_INFO) << "driver stopping service thread(s)" << endl;
 }
 
-Trunk *IVRDriver::getTrunkPort(int id)
+Trunk *PhonedevDriver::getTrunkPort(int id)
 {
 	if(id < 0 || id >= port_count)
 		return NULL;
@@ -139,18 +139,18 @@ Trunk *IVRDriver::getTrunkPort(int id)
 	return (Trunk *)ports[id];
 }
 
-ServiceDriver *IVRDriver::getService(void)
+PhonedevService *PhonedevDriver::getService(void)
 {
-	ServiceDriver *svc = &threads[thread_select++];
+	PhonedevService *svc = &threads[thread_select++];
 	if(thread_select >= thread_count)
 		thread_select = 0;
 	return svc;
 }
 
-void IVRDriver::Notify(unsigned char id)
+void PhonedevDriver::Notify(unsigned char id)
 {
 	TrunkEvent event;
-	TrunkDriver *trunk;
+	PhonedevTrunk *trunk;
 
 	if(id < 1 || id > port_count)
 		return;
@@ -163,4 +163,4 @@ void IVRDriver::Notify(unsigned char id)
 	trunk->postEvent(&event);
 }
 
-IVRDriver ivr;
+PhonedevDriver phivr;
