@@ -43,13 +43,13 @@
 
 #include "driver.h"
 
-bool TrunkDriver::ringHandler(TrunkEvent *event)
+bool PhonedevTrunk::ringHandler(TrunkEvent *event)
 {
 	char script[256];
 	int argc = 0;
-	char *start = NULL;
-	char *data;
-	char *value;
+	const char *start = NULL;
+	const char *data;
+	const char *value;
 	TrunkGroup *grp = NULL;
 
 	switch(event->id)
@@ -82,7 +82,7 @@ bool TrunkDriver::ringHandler(TrunkEvent *event)
 		start = group->getSchedule(script);
 		if(Attach(start))
 		{
-			handler = &TrunkDriver::stepHandler;
+			handler = &PhonedevTrunk::stepHandler;
 			return true;
 		}
 		rings = 0;
@@ -92,7 +92,7 @@ bool TrunkDriver::ringHandler(TrunkEvent *event)
 	case TRUNK_CPA_DIALTONE:
 	case TRUNK_TIMER_EXPIRED:
 		flags.dsp = DSP_MODE_INACTIVE;
-		handler = &TrunkDriver::idleHandler;
+		handler = &PhonedevTrunk::idleHandler;
 		return true;
 	}
 	return false;
