@@ -44,9 +44,9 @@
 #include <sys/ioctl.h>
 #include "driver.h"
 
-char TrunkDriver::status[240];
+char PhonedevTrunk::status[240];
 
-TrunkDriver::TrunkDriver(int fd, int ts) :
+PhonedevTrunk::PhonedevTrunk(int fd, int ts) :
 Trunk(ts), TimerPort()
 {
 	TrunkEvent event;
@@ -81,9 +81,9 @@ Trunk(ts), TimerPort()
 #endif
 		}
 
-	ioctl(dev, PHONE_WINK_DURATION, ivr.getWinkDuration());
+	ioctl(dev, PHONE_WINK_DURATION, phivr.getWinkDuration());
 
-	handler = &TrunkDriver::hangupHandler;
+	handler = &PhonedevTrunk::hangupHandler;
 	event.id = TRUNK_ENTER_STATE;
 
 	switch(driver)
@@ -102,20 +102,20 @@ Trunk(ts), TimerPort()
 		if(!ioctl(dev, IXJCTL_PSTN_LINETEST))
 		{
 			slog(SLOG_WARNING) << "phone" << id << ": linetest failure" << endl;
-			handler = &TrunkDriver::busyHandler;
+			handler = &PhonedevTrunk::busyHandler;
 		}
 		break;
 #endif
 	default:
 		slog(SLOG_INFO) << "phone" << id << ": generic driver started" << endl;
 	}
-	service = ivr.getService();		
+	service = phivr.getService();		
 	service->Attach(this);
 	
 	(this->*handler)(&event);
 }
 
-TrunkDriver::~TrunkDriver()
+PhonedevTrunk::~PhonedevTrunk()
 {
 	handler = NULL;
 	if(service)
@@ -136,7 +136,7 @@ TrunkDriver::~TrunkDriver()
 	slog(SLOG_INFO) << "phone" << id << ": device stopped" << endl;
 }
 
-void TrunkDriver::setCPADetect(cpatone_t tone, bool mode)
+void PhonedevTrunk::setCPADetect(cpatone_t tone, bool mode)
 {
 	switch(driver)
 	{
@@ -151,17 +151,17 @@ void TrunkDriver::setCPADetect(cpatone_t tone, bool mode)
 #endif
 	}
 }
-void TrunkDriver::getName(char *buffer)
+void PhonedevTrunk::getName(char *buffer)
 {
 	sprintf(buffer, "phone%d", id);
 }
 
-void TrunkDriver::Exit(void)
+void PhonedevTrunk::Exit(void)
 {
-	handler = &TrunkDriver::hangupHandler;
+	handler = &PhonedevTrunk::hangupHandler;
 }
 
-bool TrunkDriver::postEvent(TrunkEvent *event)
+bool PhonedevTrunk::postEvent(TrunkEvent *event)
 {
 	bool rtn = true;
 	trunkhandler_t prior;
@@ -248,15 +248,15 @@ retry:
 		break;
 	case TRUNK_STOP_STATE:
 		endTimer();
-		handler = &TrunkDriver::stepHandler;
+		handler = &PhonedevTrunk::stepHandler;
 		break;
 	case TRUNK_EXIT_STATE:
 		break;
 	case TRUNK_MAKE_BUSY:
-		handler = &TrunkDriver::busyHandler;
+		handler = &PhonedevTrunk::busyHandler;
 		break;
 	case TRUNK_MAKE_IDLE:
-		handler = &TrunkDriver::idleHandler;
+		handler = &PhonedevTrunk::idleHandler;
 		break;
 	default:
 		rtn = false;
@@ -270,7 +270,7 @@ retry:
 	return rtn;
 }
 
-void TrunkDriver::getEvents(void)
+void PhonedevTrunk::getEvents(void)
 {
 	union telephony_exception exc;
 	char digit;
@@ -434,31 +434,31 @@ void TrunkDriver::getEvents(void)
 	}		
 }
 		
-void TrunkDriver::setTimer(timeout_t ptimer)
+void PhonedevTrunk::setTimer(timeout_t ptimer)
 {
 	TimerPort::setTimer(ptimer);
 	if(!service->isThread())
 		service->Update();
 }
 
-void TrunkDriver::incTimer(timeout_t ptimer)
+void PhonedevTrunk::incTimer(timeout_t ptimer)
 {
 	TimerPort::incTimer(ptimer);
 	service->Update();
 }
 
-unsigned long TrunkDriver::getIdleTime(void)
+unsigned long PhonedevTrunk::getIdleTime(void)
 {
 	time_t now;
 
 	time(&now);
-	if(handler == &TrunkDriver::idleHandler)
+	if(handler == &PhonedevTrunk::idleHandler)
 		return now - idle;
 
 	return 0;
 }
 
-void TrunkDriver::setHookState(bool offhook)
+void PhonedevTrunk::setHookState(bool offhook)
 {
 	if(offhook == flags.offhook)
 		return;
@@ -471,7 +471,7 @@ void TrunkDriver::setHookState(bool offhook)
 	flags.offhook = offhook;
 }
 
-struct phone_capability *TrunkDriver::getCapability(phone_cap cid, int sub)
+struct phone_capability *PhonedevTrunk::getCapability(phone_cap cid, int sub)
 {
 	int cap;
 
