@@ -59,8 +59,7 @@
 #include <pk_cid.h>
 #include <pk_fax.h>
 
-class TrunkDriver;
-class DSPDevice;
+class PikaTrunk;
 
 typedef enum
 {
@@ -74,13 +73,13 @@ typedef struct
 	TDeviceHandle dsp[MAX_DSP_DEVICES];
 } trunkdsp_t;
 
-typedef	bool (TrunkDriver::*trunkhandler_t)(TrunkEvent *event);
+typedef	bool (PikaTrunk::*trunkhandler_t)(TrunkEvent *event);
 typedef void PK_CALLBACK(*pikacall_t)(PK_U32, PK_U32, PK_U32, PK_U32);
 
-class TrunkDriver : private TimerPort, private Trunk
+class PikaTrunk : private TimerPort, private Trunk
 {
 private:
-	friend class IVRDriver;
+	friend class PikaDriver;
 
 	static char *status;
 	static void callback(PK_U32 id, PK_U32 event, PK_U32 p1, PK_U32 p2);
@@ -99,8 +98,8 @@ private:
 
 	unsigned char cidbuf[PK_CID_BUFFER_SIZE];
 
-	TrunkDriver(TResourceHandle hRes, trunknti_t nti, int card, int ts);
-	~TrunkDriver();
+	PikaTrunk(TResourceHandle hRes, trunknti_t nti, int card, int ts);
+	~PikaTrunk();
 
 	bool hangupHandler(TrunkEvent *event);
 	bool idleHandler(TrunkEvent *event);
@@ -135,7 +134,7 @@ public:
 		{return hDsp;};
 };
 
-class RecordAudio : private AudioFile, public Service
+class PikaRecord : private AudioFile, public Service
 {
 private:
 	TResourceHandle hDsp;
@@ -148,11 +147,11 @@ private:
 
 public:
 	timeout_t Stop(void);
-	RecordAudio(TrunkDriver *trunk);
-	~RecordAudio();
+	PikaRecord(PikaTrunk *trunk);
+	~PikaRecord();
 };
 
-class PlayAudio : private AudioFile, public Service
+class PikaPlay : private AudioFile, public Service
 {
 private:
 	TResourceHandle hDsp;
@@ -166,25 +165,25 @@ private:
 
 public:
 	timeout_t Stop(void);
-	PlayAudio(TrunkDriver *trunk);
-	~PlayAudio();
+	PikaPlay(PikaTrunk *trunk);
+	~PikaPlay();
 };
 
-class ConfigDriver : public Keydata
+class PikaConfig : public Keydata
 {
 public:
-	ConfigDriver();
+	PikaConfig();
 
 	inline int getAudioBuffers(void)
 		{return atoi(getLast("buffers"));};
 };
 
-class IVRDriver : public Driver, public ConfigDriver
+class PikaDriver : public Driver, public PikaConfig
 {
 private:
 	static char *names[];
 
-	TrunkDriver **ports;
+	PikaTrunk **ports;
 	trunkdsp_t *dsps;
 
 	unsigned card_count;
@@ -192,8 +191,8 @@ private:
 	unsigned dsp_count;
 
 public:
-	IVRDriver();
-	~IVRDriver();
+	PikaDriver();
+	~PikaDriver();
 
 	int Start(void);
 	void Stop(void);
@@ -208,4 +207,4 @@ public:
 	aaScript *getScript(void);
 };
 
-extern IVRDriver ivr;
+extern PikaDriver pikaivr;
