@@ -44,13 +44,13 @@
 #include "driver.h"
 #include <sys/ioctl.h>
 
-bool TrunkDriver::idleHandler(TrunkEvent *event)
+bool PikaTrunk::idleHandler(TrunkEvent *event)
 {
 	char script[256];
 	int argc = 0;
-	char *start = NULL;
-	char *data;
-	char *value;
+	const char *start = NULL;
+	const char *data;
+	const char *value;
 	TrunkGroup *grp = NULL;
 	char *sp;
 
@@ -84,26 +84,18 @@ bool TrunkDriver::idleHandler(TrunkEvent *event)
 		return true;
 	case TRUNK_MAKE_BUSY:
 		flags.trunk = TRUNK_MODE_UNAVAILABLE;
-		handler = &TrunkDriver::busyHandler;
+		handler = &PikaTrunk::busyHandler;
 		return true;
 	case TRUNK_MAKE_IDLE:
 		return true;
 	case TRUNK_START_SCRIPT:
 		flags.trunk = TRUNK_MODE_OUTGOING;
-	case TRUNK_RING_START:
+
+// Matt B -- code split from TRUNK_RING_START to keep the flow clear
+	     
 		start = event->parm.argv[0];
-		if(start)
-		{
-			if(strchr(start, '='))
-				start = group->getSchedule(script);
-			else
-				++argc;
-		}
-		rings = 0;
-		if(flags.trunk == TRUNK_MODE_INACTIVE)
-			flags.trunk = TRUNK_MODE_INCOMING;
-		if(!start)
-			start = group->getSchedule(script);
+		++argc;
+		
 		if(Attach(start))
 		{
 			while(event->parm.argv[argc])
@@ -114,25 +106,56 @@ bool TrunkDriver::idleHandler(TrunkEvent *event)
 				if(data && value)
 					setConstant(data, value);
 			}		
-			if(flags.trunk == TRUNK_MODE_OUTGOING)
-			{
-//				handler = &TrunkDriver::seizeHandler;
-				group->incOutgoing();
-			}
+
+		  // Looks like following call needed to start script executing?
+		  // Maybe should be stepHandler?
+		  handler = &PikaTrunk::stepHandler;
+		  //		  handler = &PikaTrunk::seizeHandler;  // Does what?
+
+		  group->incOutgoing();
+			
+		  return true;
+		}
+
+		flags.trunk = TRUNK_MODE_INACTIVE;
+		slog(SLOG_ERROR) << pikaivr.getCardName(card) << id << ": " << start << ": cannot start" << endl;
+		return true;		
+// Matt B
+	case TRUNK_RING_START:
+		start = event->parm.argv[0];
+		if(start)
+		{
+			if(strchr(start, '='))
+				start = group->getSchedule(script);
 			else
+				++argc;
+		}
+		rings = 0;
+		flags.trunk = TRUNK_MODE_INCOMING;
+		if(!start)
+			start = group->getSchedule(script);
+
+		if(Attach(start))
+		{
+			while(event->parm.argv[argc])
 			{
-				handler = &TrunkDriver::stepHandler;
-				group->incIncoming();
-			}
+				strcpy(script, event->parm.argv[argc++]);
+				data = strtok_r(script, "=", &sp);
+				value = strtok_r(NULL, "=", &sp);
+				if(data && value)
+					setConstant(data, value);
+			}		
+			handler = &PikaTrunk::stepHandler;
+			group->incIncoming();
 			return true;
 		}
 		flags.trunk = TRUNK_MODE_INACTIVE;
-		slog(SLOG_ERROR) << ivr.getCardName(card) << id << ": " << start << ": cannot start" << endl;
+		slog(SLOG_ERROR) << pikaivr.getCardName(card) << id << ": " << start << ": cannot start" << endl;
 		return true;		
 	case TRUNK_RINGING_ON:
 		rings = 1;
 		group->incIncoming();
-		handler = &TrunkDriver::ringHandler;
+		handler = &PikaTrunk::ringHandler;
 		return true;
 	}
 	return false;
