@@ -45,7 +45,7 @@
 #include <sys/ioctl.h>
 #include <sys/stat.h>
 
-PlayAudio::PlayAudio(TrunkDriver *trunk) :
+PikaPlay::PikaPlay(PikaTrunk *trunk) :
 Service((Trunk *)trunk, keythreads.priAudio()), AudioFile()
 {
 	reset = false;
@@ -53,7 +53,7 @@ Service((Trunk *)trunk, keythreads.priAudio()), AudioFile()
 	clrAudio();
 }
 
-PlayAudio::~PlayAudio()
+PikaPlay::~PikaPlay()
 {
 	char buffer[12];
 	clrAudio();
@@ -69,12 +69,12 @@ PlayAudio::~PlayAudio()
 	}
 }
 
-char *PlayAudio::getContinuation(void)
+char *PikaPlay::getContinuation(void)
 {
 	return getPlayfile();
 }
 
-timeout_t PlayAudio::Stop(void)
+timeout_t PikaPlay::Stop(void)
 {
 	clrAudio();
 	stopped = true;
@@ -83,10 +83,10 @@ timeout_t PlayAudio::Stop(void)
 		reset = false;
 		PK_AUDIO_Reset(hDsp);
 	}
-	return 120 * ivr.getAudioBuffers() + keythreads.getResetDelay();
+	return 120 * pikaivr.getAudioBuffers() + keythreads.getResetDelay();
 }
 
-void PlayAudio::Initial(void)
+void PikaPlay::Initial(void)
 {
 	unsigned codec, speed, rate, len, count = 0;
 	char buffer[32];
@@ -176,9 +176,9 @@ void PlayAudio::Initial(void)
 	samples = tosamples(getEncoding(), bufsize);
 }
 
-void PlayAudio::Run(void)
+void PikaPlay::Run(void)
 {
-	int buffers = ivr.getAudioBuffers();
+	int buffers = pikaivr.getAudioBuffers();
 	int frame = 0;
 	int len = 0;
 	audioerror_t status = AUDIO_SUCCESS;
@@ -245,7 +245,7 @@ void PlayAudio::Run(void)
 	Success();
 }
 
-bool TrunkDriver::playHandler(TrunkEvent *event)
+bool PikaTrunk::playHandler(TrunkEvent *event)
 {
 	switch(event->id)
 	{
@@ -253,12 +253,12 @@ bool TrunkDriver::playHandler(TrunkEvent *event)
 		stopServices();
 	case TRUNK_SERVICE_SUCCESS:
 		TrunkSignal(TRUNK_SIGNAL_STEP);
-		handler = &TrunkDriver::stepHandler;
+		handler = &PikaTrunk::stepHandler;
 		return true;
 	case TRUNK_SERVICE_FAILURE:
 		setSymbol("error", "play-failed");
 		TrunkSignal(TRUNK_SIGNAL_ERROR);
-		handler = &TrunkDriver::stepHandler;
+		handler = &PikaTrunk::stepHandler;
 		return true;
 	case TRUNK_ENTER_STATE:
 		debug->DebugState(this, "play");
@@ -274,7 +274,7 @@ bool TrunkDriver::playHandler(TrunkEvent *event)
 		endTimer();
 		getVPResource();
 		Trunk::setDTMFDetect();
-		thread = new PlayAudio(this);
+		thread = new PikaPlay(this);
 		thread->Start();
 		return true;
 	}
