@@ -62,6 +62,10 @@
 
 #include <stdlib.h>
 
+#ifndef	COMMON_TPPORT_TYPE_DEFINED
+typedef	short	tpport_t;
+#endif
+
 /* Bayonne uses a universal event record for all driver plugins and
    state handlers.  Not all drivers impliment the entire set of events
    and some drivers have specific events associated with their unique
@@ -72,6 +76,14 @@ class Trunk;
 class Service;
 class phTone;
 
+typedef enum {
+	MODULE_DELIVERY,
+	MODULE_SENDFILE,
+	MODULE_SENDFAX,
+	MODULE_NOTIFY,
+	MODULE_TGI
+}	modtype_t;
+
 typedef enum {
 	// step change requests
 	TRUNK_STEP_HANGUP = 0,
@@ -575,37 +587,37 @@ public:
 	/**
 	 * Get the driver and tgi base directories.
 	 */
-	inline char *getLibexec(void)
+	inline const char *getLibexec(void)
 		{return getLast("libexec");};
 
 	/**
 	 * Get the primary working storage for writable messages.
 	 */
-	inline char *getDatafiles(void)
+	inline const char *getDatafiles(void)
 		{return getLast("datafiles");};
 
 	/**
 	 * Get the runfile directory.
 	 */
-	inline char *getRunfiles(void)
+	inline const char *getRunfiles(void)
 		{return getLast("runfiles");};
 
 	/**
 	 * Get the spool directory.
 	 */
-	inline char *getSpool(void)
+	inline const char *getSpool(void)
 		{return getLast("spool");};
 
 	/**
 	 * Get the primary script prefix directory.
 	 */
-	inline char *getScriptFiles(void)
+	inline const char *getScriptFiles(void)
 		{return getLast("scripts");};
 
 	/**
 	 * Get the pre-cache directory.
 	 */
-	inline char *getCache(void)
+	inline const char *getCache(void)
 		{return getLast("precache");};
 };
 
@@ -670,7 +682,7 @@ public:
 	 *
 	 * @return default initial password.
 	 */
-	inline char *getPassword(void)
+	inline const char *getPassword(void)
 		{return getLast("password");};
 };
 
@@ -848,6 +860,21 @@ public:
 	 */
 	inline int getPriority(void)
 		{return atoi(getLast("priority"));};
+
+	/**
+	 * Get scheduling policy to use.
+	 *
+	 * @return policy id, or "0" for default.
+	 */
+	int getPolicy(void);
+
+	/**
+	 * Get memory locking and local pages.
+	 *
+	 * @return number of k of stack to pre-allocate.
+	 */
+	inline int getPages(void)
+		{return atoi(getLast("pages"));};
 };
 
 /**
@@ -900,7 +927,7 @@ public:
 	 *
 	 * @return name of trunk group.
 	 */
-	inline char *getName(void)
+	inline const char *getName(void)
 		{return getLast("name");};
 
 	/**
@@ -957,7 +984,7 @@ public:
 	 * @return name of scheduled script.
 	 * @param buffer to copy schedule information into.
 	 */
-	char *getSchedule(char *buf);
+	const char *getSchedule(char *buf);
 
 	/**
 	 * Used when mapping trunk groups to activated trunks.
@@ -989,7 +1016,7 @@ public:
 	 *
 	 * @return node id.
 	 */
-	inline char *getNode(void)
+	inline const char *getNode(void)
 		{return getLast("node");};
 
 	/**
@@ -997,7 +1024,7 @@ public:
 	 *
 	 * @return token seperator.
 	 */
-	inline char *getToken(void)
+	inline const char *getToken(void)
 		{return getLast("token");};
 
 	/**
@@ -1018,7 +1045,7 @@ public:
 	 *
 	 * @return schedule name.
 	 */
-	inline char *getDefault(void)
+	inline const char *getDefault(void)
 		{return getLast("default");};
 
 	/**
@@ -1104,6 +1131,16 @@ public:
 	 */
 	void loadFunctions(void);
 
+	/**
+	 * Attemot to load DSO based protocol modules into the server.
+	 */
+	void loadModules(void);
+
+	/**
+	 * Attempt to load TGI based resident interpreters.
+	 */
+	void loadTGI(void);
+
 	/**
 	 * Attempt to load DSO network management interfaces.
 	 */
@@ -1237,6 +1274,7 @@ private:
 	int cdrc;
 	numbersymbol_t numbers[5];
 
+	bool scrLibonce(void);
 	bool scrLibexec(void);
 	bool scrHangup(void);
 	bool scrDebug(void);
@@ -1257,8 +1295,6 @@ private:
 	bool scrAppend(void);
 	bool scrDial(void);
 	bool scrTransfer(void);
-	bool scrPack(void);
-	bool scrUnpack(void);
 	bool scrSpeak(void);
 	bool scrLookup(void);
 	bool scrLogin(void);
@@ -1266,6 +1302,10 @@ private:
 	bool scrSession(void);
 	bool scrRetry(void);
 	bool scrSubmit(void);
+	bool scrDeliver(void);
+	bool scrSendfile(void);
+	bool scrNotify(void);
+	bool scrSendfax(void);
 
 protected:
 	static ScriptSymbol globals;
@@ -1293,6 +1333,8 @@ protected:
 		bool reset: 1;
 		bool timer : 1;
 		bool audio: 1;
+		bool once : 1;
+		unsigned temp : 4;
 		trunkmode_t trunk: 2;
 		dspmode_t dsp: 4;
 	} flags;
@@ -1582,6 +1624,8 @@ protected:
 	bool putSymbol(char **argv);
 	bool submit(char **argv);
 	bool login(char **argv);
+	bool startScript(int id, char **argv);
+	bool ringScript(int id, char **argv);
 
 public:
 	/**
@@ -1809,6 +1853,12 @@ public:
 	 */
 	virtual void DebugStep(Trunk *trunk, scriptline_t *line)
 		{DebugState(trunk, "step");};
+
+	/**
+	 * Debug interface for fifo "debug" statement.
+	 */
+	virtual bool DebugFifo(char **argv)
+		{return true;};
 };
 
 /**
@@ -1922,12 +1972,28 @@ protected:
 	friend class Trunk;
 	Database();
 
+	/**
+	 * Initialize script environment.
+	 *
+ 	 * @param trunk handle.
+	 */
+	virtual void Initialize(Trunk *trunk)
+		{return;};
+
+	/**
+	 * Finalize script environment.
+	 *
+	 * @param trunk handler.
+	 */
+ 	virtual void Finalize(Trunk *trunk)
+		{return;};
+
 	/**
 	 * Post lookup request.  This could send a packet or reply
 	 * immediately.  A negative value indicates an error.
 	 *
 	 * @return execution delay for transaction to sleep.
-	 * @parm trunk handle.
+	 * @param trunk handle.
 	 */
 	virtual int Lookup(unsigned seq, Trunk *trunk) = 0;
 
@@ -1936,7 +2002,7 @@ protected:
 	 * threads.
 	 *
 	 * @return error message or successful.
-	 * @parm trunk handle.
+	 * @param trunk handle.
 	 */
 	virtual char *Submit(Trunk *trunk)
 		{return "submit-not-supported";};
@@ -1945,7 +2011,7 @@ protected:
 	 * Support login request if resource sets sessions.
 	 *
 	 * @return execution delay for transaction to sleep.
-	 * @parm trunk handle.
+	 * @param trunk handle.
 	 */
 	virtual int Login(unsigned seq, Trunk *trunk)
 		{return -1;};
@@ -1953,7 +2019,7 @@ protected:
 	/**
 	 * Logout and disconnect an active session object.
 	 *
-	 * @parm trunk handle.
+	 * @param trunk handle.
 	 */
 	virtual void Logout(Trunk *trunk)
 		{return;};
@@ -1962,7 +2028,7 @@ protected:
 	 * Mailbox session request, assumes login as well.
 	 *
 	 * @return execution delay for transaction to sleep.
-	 * @parm trunk handle.
+	 * @param trunk handle.
 	 */
 	virtual int Session(unsigned seq, char *keyword, Trunk *trunk)
 		{return -1;};
@@ -2162,13 +2228,114 @@ public:
 	virtual void Refresh(int seconds) = 0;	
 };
 
+/**
+ * This class is used for interfacing to DSO loaded TGI interpreters.
+ *
+ * @short TGI interpreter module.
+ * @author David Sugar <dyfet@ostel.com>
+ */
+class TGI
+{
+private:
+	static TGI *first;
+	TGI *next;
+
+protected:
+	TGI();
+
+	/**
+	 * Check a file extension to see if it belongs to a first
+	 * stage tgi script interpreter (avoids second fork).
+	 *
+	 * @return true if claimed.
+	 * @param extension.
+	 */
+	virtual bool getExtension(char *ext)
+		{return false;};
+
+public:
+	/**
+	 * Check command for interpreter and, if is, execute it.  If
+	 * so it doesn't return but uses "exit".  This is a "second"
+	 * stage tgi mod interface and is effective for single session
+	 * interpreter libraries.
+	 *
+	 * @param script name resolved.
+	 * @param argument list.
+	 */
+	virtual void Script(char *cmd, char **args)
+		{return;};
+
+	/**
+	 * Execute a first stage interpreter, uses local functions.
+	 *
+	 * @return shell exit code.
+	 * @param fifo file descriptor.
+	 * @param port number.
+	 * @param unparsed command string.
+	 */
+	virtual int Parse(int fd, int port, char *cmd)
+		{return -1;};	
+
+	friend void getInterp(char *cmd, char **args);
+	friend TGI *getInterp(char *cmd);
+};
+	
+/**
+ * Modules are used for protocol modules and detached threads used to
+ * service key Bayonne protocols and interfaces.  These are done as
+ * loadable modules and may be replaced with application specific
+ * interfaces.
+ *
+ * @short Module interface class.
+ * @author David Sugar <dyfet@ostel.com>
+ */
+class Module
+{
+private:
+	static Module *first;
+	Module *next;
+
+protected:
+	Module();
+
+	/**
+	 * Get the "type" identifer of this module.
+	 *
+	 * @return type id.
+	 */
+	virtual modtype_t getType(void) = 0;
+
+	/**
+	 * Get the "name" identifer of this module.
+	 *
+	 * @return name string.
+	 */
+	virtual char *getName(void) = 0;
+
+public:
+	/**
+	 * Execute the script request.  Usually this involves creating
+	 * a detached service thread.
+	 *
+	 * @return error message or NULL.
+	 * @param trunk object to reference.
+	 */
+	virtual char *Dispatch(Trunk *trunk) = NULL;
+
+public:
+	friend Module *getModule(modtype_t mod, const char *name = NULL);
+};
+
 /**
  * Sessions are used for "garbage collected" entities which may be
  * detached and removed after an expiration time rather than falling
  * out of scope immediately.  This process is managed by the scheduler
  * thread.
+ *
+ * @short Garbage collectable objects.
+ * @author David Sugar <dyfet@ostel.com>
  */
-
 class Session
 {
 private:
@@ -2198,6 +2365,53 @@ protected:
 	virtual time_t getExpires(void) = 0;
 };
 
+/**
+ * Protocols are used for processing transactional requests such as
+ * those performed thru modules, but thru a TCP protocol.  These support
+ * the resolver thread.
+ *
+ * @short resolved network protocol session interface.
+ * @author David Sugar <dyfet@ostel.com>
+ */
+class Protocol : public Keydata, public InetHostAddress, public ThreadLock
+{
+private:
+	friend class Resolver;
+	static Protocol *first;
+	Protocol *next;
+	Semaphore *sessions;
+	tpport_t port;
+
+	void Update(InetHostAddress addr);
+public:
+	Protocol(const char *keypath, tpport_t port);
+	~Protocol();
+
+	/**
+	 * Get inet host address for this service.
+	 *
+	 * @return inet host address of server.
+	 */
+	InetHostAddress getAddress(void);
+
+	/**
+	 * Get inet port address of this service.
+	 *
+	 * @return inet port address of service.
+	 */
+	inline tpport_t getPort(void)
+		{return port;};
+
+	/**
+	 * Get client connection limiting semaphore that is used as the
+	 * starting semaphore for the client connection thread.
+	 *
+	 * @return semaphore session limiter.
+	 */
+	inline Semaphore *getSessions(void)
+		{return sessions;};
+};
+
 extern KeyServer keyserver;
 extern KeyThreads keythreads;
 extern KeyMemory keymemory;
