@@ -84,8 +84,7 @@ ScriptCommand("/bayonne/script")
 		{"transfer", (scriptmethod_t)&Trunk::scrTransfer, &ScriptCommand::chkHasArgs},
 		{"pause", (scriptmethod_t)&Trunk::scrPause, &ScriptCommand::chkHasArgs},
 		{"libexec", (scriptmethod_t)&Trunk::scrLibexec, &ScriptCommand::chkHasArgs},
-		{"pack", (scriptmethod_t)&Trunk::scrPack, &ScriptCommand::chkHasArgs},
-		{"unpack", (scriptmethod_t)&Trunk::scrUnpack, &ScriptCommand::chkHasArgs},
+		{"libonce", (scriptmethod_t)&Trunk::scrLibonce, &ScriptCommand::chkHasArgs},
 		{"speak", (scriptmethod_t)&Trunk::scrSpeak, &ScriptCommand::chkHasArgs},
 		{"lookup", (scriptmethod_t)&Trunk::scrLookup, &ScriptCommand::chkHasArgs},
 		{"retry", (scriptmethod_t)&Trunk::scrRetry, &ScriptCommand::chkHasArgs},
@@ -93,6 +92,10 @@ ScriptCommand("/bayonne/script")
 		{"logout", (scriptmethod_t)&Trunk::scrLogout, &ScriptCommand::chkNoArgs},
 		{"submit", (scriptmethod_t)&Trunk::scrSubmit, &ScriptCommand::chkHasArgs},
 		{"session", (scriptmethod_t)&Trunk::scrSession, &ScriptCommand::chkHasArgs},
+		{"deliver", (scriptmethod_t)&Trunk::scrDeliver, &ScriptCommand::chkHasArgs},
+		{"sendfax", (scriptmethod_t)&Trunk::scrSendfax, &ScriptCommand::chkHasArgs},
+		{"sendfile", (scriptmethod_t)&Trunk::scrSendfile, &ScriptCommand::chkHasArgs},
+		{"notify", (scriptmethod_t)&Trunk::scrNotify, &ScriptCommand::chkHasArgs},
 		{NULL, NULL, NULL}};
 
 	// pre-load some useful compiler "$constants", some of which
