@@ -52,8 +52,6 @@ Keydata("/bayonne/localize")
 	{"primarycurrency", "dollar"},
 	{"primarychange", "cent"},
 	{"convertcurrency", "1.00"},
-	{"currencyand", "and"},
-	{"currencyor", "or"},
 	{NULL, NULL}};
 
 	Load(keydefs);
@@ -128,7 +126,7 @@ void KeyServer::loadGroups(void)
 	new TrunkGroup();
 	slog(SLOG_DEBUG) << "loading default trunk group" << endl;
 	
-	group = TrunkGroup::first->getLast("groups");
+	group = (char *)TrunkGroup::first->getLast("groups");
 	if(!group)
 		return;
 
@@ -171,17 +169,32 @@ Keydata("/bayonne/threads")
 	{"stepinterval", "18"},
 	{"interval", "15"},
 	{"refresh", "5"},
+	{"policy", "other"},
+	{"pages", "0"},
 	{NULL, NULL}};
 
-	char *cp;
-
-	cp = getLast("pri");
+	const char *cp = getLast("pri");
+	
 	if(cp)
 		setValue("priority", cp);
 
 	Load(defpaths);
 }
 
+int KeyThreads::getPolicy()
+{
+	const char *cp = getLast("policy");
+#ifdef	SCHED_RR
+	if(!stricmp(cp, "rr"))
+		return SCHED_RR;
+#endif
+#ifdef	SCHED_FIFO
+	if(!stricmp(cp, "fifo"))
+		return SCHED_FIFO;
+#endif
+	return 0;
+}
+
 KeyMailbox::KeyMailbox() :
 Keydata("/bayonne/mailbox")
 {
@@ -211,7 +224,7 @@ Keydata("/bayonne/memory")
 
 int KeyThreads::priResolver(void)
 {
-	char *cp = getLast("resolver");
+	const char *cp = getLast("resolver");
 	if(cp)
 		return atoi(cp);
 
@@ -222,9 +235,8 @@ int KeyThreads::getResolver(void)
 {
 	char buf[32];
 	int cnt;
-	char *cp;
-
-	cp = getLast("resolver");
+	const char *cp = getLast("resolver");
+	
 	if(!cp)
 		return 0;
 
@@ -308,12 +320,12 @@ char *Plugins::getDriverName(void)
 {
 	static char name[33];
 
-	char *drv = getLast("driver");
+	const char *drv = getLast("driver");
 	char *cp = strrchr(drv, '/');
 	if(cp)
 		++cp;
 	else
-		cp = drv;
+		cp = (char *)drv;
 	strncpy(name, cp, 32);
 	name[33] = 0;
 	cp = strrchr(name, '.');
@@ -331,7 +343,7 @@ void Plugins::loadManagers(void)
 	char list[412];
 	char *cp;
 
-	cp = getLast("managers");
+	cp = (char *)getLast("managers");
 	if(!cp)
 		return;
 
@@ -364,7 +376,7 @@ void Plugins::loadAuditing(void)
 	char list[412];
 	char *cp;
 
-	cp = getLast("auditing");
+	cp = (char *)getLast("auditing");
 	if(!cp)
 		return;
 
@@ -391,14 +403,13 @@ void Plugins::loadAuditing(void)
 	}
 }
 
-
 void Plugins::loadFunctions(void)
 {
 	char path[256];
 	char list[512];
 	char *cp;
 
-	cp = getLast("functions");
+	cp = (char *)getLast("functions");
 	if(!cp)
 		return;
 
@@ -424,13 +435,78 @@ void Plugins::loadFunctions(void)
 	}
 }
 
+void Plugins::loadModules(void)
+{
+	char path[256];
+	char list[512];
+	char *cp;
+
+	cp = (char *)getLast("modules");
+	if(!cp)
+		return;
+
+	strcpy(list, cp);
+	cp = strtok(list, " \t\n;,");
+	while(cp)
+	{
+		if(!*cp)
+			break;
+
+		if(*cp == '/')
+			path[0] = 0;
+		else
+		{
+			strcpy(path, keypaths.getLibexec());
+			strcat(path, "/bayonne/");
+		}
+		strcat(path, cp);
+		if(*cp != '/')
+			strcat(path, ".mod");
+		new DSO(path);
+		cp = strtok(NULL, " \t\n;,");
+	}
+}
+
+void Plugins::loadTGI(void)
+{
+	char path[256];
+	char list[512];
+	char *cp;
+
+	cp = (char *)getLast("tgi");
+	if(!cp)
+		return;
+
+	strcpy(list, cp);
+	cp = strtok(list, " \t\n;,");
+	while(cp)
+	{
+		if(!*cp)
+			break;
+
+		if(*cp == '/')
+			path[0] = 0;
+		else
+		{
+			strcpy(path, keypaths.getLibexec());
+			strcat(path, "/bayonne/");
+		}
+		strcat(path, cp);
+		if(*cp != '/')
+			strcat(path, ".tgi");
+		new DSO(path);
+		cp = strtok(NULL, " \t\n;,");
+	}
+}
+
+
 void Plugins::loadTranslators(void)
 {
 	char path[256];
 	char list[512];
 	char *cp;
 
-	cp = getLast("languages");
+	cp = (char *)getLast("languages");
 	if(!cp)
 		return;
 
@@ -470,7 +546,7 @@ void Plugins::loadExtensions(void)
 void Plugins::loadDatabase(void)
 {
 	char path[256];
-	char *d = getLast("database");
+	char *d = (char *)getLast("database");
 
 	if(*d != '/')
 	{
@@ -488,7 +564,7 @@ void Plugins::loadDatabase(void)
 void Plugins::loadDebug(void)
 {
 	char path[256];
-	char *d = getLast("debug");
+	char *d = (char *)getLast("debug");
 
 	if(!d)
 	{
@@ -510,7 +586,7 @@ void Plugins::loadDebug(void)
 DSO *Plugins::loadStatMon(void)
 {
 	char path[256];
-	char *s = getLast("statmon");
+	char *s = (char *)getLast("statmon");
 
 	if(!s)
 		return NULL;
@@ -529,7 +605,7 @@ DSO *Plugins::loadStatMon(void)
 DSO *Plugins::loadDriver(void)
 {
 	char path[256];
-	char *drv = getLast("driver");
+	char *drv = (char *)getLast("driver");
 	
 	if(*drv != '/')
 	{
@@ -546,7 +622,7 @@ DSO *Plugins::loadDriver(void)
 KeyTones::KeyTones() :
 Keydata("/bayonne/tones")
 {
-	char *tones = getLast("tones");
+	char *tones = (char *)getLast("tones");
 	int v1, v2, v3;
 	char *tone;
 
@@ -554,7 +630,7 @@ Keydata("/bayonne/tones")
 	while(tones)
 	{
 		v1 = v2 = v3 = 0;
-		tone = getLast(tones);
+		tone = (char *)getLast(tones);
 		if(!tone)
 		{
 			tones = strtok(NULL, " \t\n");
@@ -600,7 +676,7 @@ Keydata("/bayonne/trunks"), CallStat()
 		Load(namebuf);
 		*namebuf = '~';
 		Load(namebuf);
-		cp = getLast("trunks");
+		cp = (char *)getLast("trunks");
 		if(cp)
 			cp = strtok(cp, " ,;\t\n");
 		while(cp)
@@ -630,9 +706,9 @@ Keydata("/bayonne/trunks"), CallStat()
 		first = this;
 }	
 
-char *TrunkGroup::getSchedule(char *buf)
+const char *TrunkGroup::getSchedule(char *buf)
 {
-	char *scr = getLast("script");	// check for .conf override
+	const char *scr = getLast("script");	// check for .conf override
 	if(scr)
 		return scr;
 
