@@ -47,6 +47,8 @@ Server *Server::first = NULL;
 Audit *Audit::first = NULL;
 Auditdata Audit::keys;
 Translator *Translator::first = NULL;
+TGI *TGI::first = NULL;
+Module *Module::first = NULL;
 Sync *Sync::first = NULL;
 
 Auditdata::Auditdata()
@@ -264,6 +266,66 @@ Keydata("/bayonne/statmon")
 	Load("~bayonne/statmon");
 }
 
+TGI::TGI()
+{
+	next = first;
+	first = this;
+}
+
+TGI *getInterp(char *cmd)
+{
+	TGI *tgi = TGI::first;
+	char *ext;
+	char buffer[512];
+	strcpy(buffer, cmd);
+	cmd = strtok_r(buffer, " \t\n", &ext);
+	ext = strrchr(cmd, '.');
+	
+	while(tgi)
+	{
+		if(tgi->getExtension(ext))
+			return tgi;
+		tgi = tgi->next;
+	}
+	return NULL;
+}
+
+void getInterp(char *cmd, char **args)
+{
+	TGI *tgi = TGI::first;
+
+	while(tgi)
+	{
+		tgi->Script(cmd, args);
+		tgi = tgi->next;
+	}
+}
+
+Module::Module()
+{
+	next = first;
+	first = this;
+}
+
+Module *getModule(modtype_t mtype, const char *name)
+{
+	Module *mod = Module::first;
+
+	while(mod)
+	{
+		if(mod->getType() == mtype)
+		{
+			if(!name)
+				return mod;
+
+			if(!stricmp(name, mod->getName()))
+				return mod;
+		}
+		mod = mod->next;
+	}
+	return NULL;
+}
+	
 Debug *debug = NULL;
 Driver *driver = NULL;
 StatMon *statmon = NULL;
