@@ -140,6 +140,35 @@ bool Fifo::submit(char **argv)
 	return trunk->postEvent(&event);
 }
 
+
+bool Fifo::ringScript(int argc, char **argv)
+{
+	Trunk *trunk = getTrunk(argv[1]);
+	TrunkEvent event;
+
+	if(!trunk || !argv[2])
+		return false;
+
+	event.id = TRUNK_RING_START;
+	event.parm.argv = &argv[2];
+
+	return trunk->postEvent(&event);
+}
+
+bool Fifo::startScript(int argc, char **argv)
+{
+	Trunk *trunk = getTrunk(argv[1]);	
+	TrunkEvent event;
+	
+	if(!trunk || !argv[2])
+		return false;
+
+	event.id = TRUNK_START_SCRIPT;
+	event.parm.argv = &argv[2];
+
+	return trunk->postEvent(&event);
+}
+
 bool Fifo::exitPid(char **argv)
 {
 	Trunk *trunk = getTrunk(argv[1]);
@@ -167,7 +196,7 @@ bool Fifo::Command(const char *cmd)
 	char *arg;
 	char *sp;
 	char *ptr;
-	char *token = keyserver.getToken();
+	const char *token = keyserver.getToken();
 	int tlen = strlen(token);
 
 	strncpy(buffer, cmd, sizeof(buffer) - 1);
@@ -182,12 +211,16 @@ bool Fifo::Command(const char *cmd)
 			++ptr;
 	
 		ptr = strtok_r(ptr, "\n", &sp);	
-		while(NULL != (sp = strstr(buffer, token)))
+		while(NULL != (sp = strstr(ptr, token)))
 		{
 			argv[argc++] = ptr;
 			*sp = 0;
 			ptr = sp + tlen;
 		}
+		while(isspace(*ptr))
+			++ptr;
+		if(*ptr)
+			argv[argc++] = ptr;
 	}
 	else
 	{
@@ -242,6 +275,16 @@ bool Fifo::Command(const char *cmd)
 		rts = submit(argv);
 	else if(!stricmp(argv[0], "login"))
 		rts = login(argv);
+	else if(!stricmp(argv[0], "debug"))
+		rts = debug->DebugFifo(argv);
+	else if(!stricmp(argv[0], "ring"))
+		rts = ringScript(argc, argv);
+
+//  MattB
+
+	else if(!stricmp(argv[0], "start"))
+		rts = startScript(argc, argv);	
+
 	LeaveMutex();
 	return rts;
 }
