@@ -76,11 +76,11 @@ void Scheduler::Initial(void)
 		sched.close();
 
 	sched.open("/etc/bayonne.sched");
-	if(!sched)
+	if(!sched.is_open())
 		slog(SLOG_WARNING) << "/etc/bayonne.sched: cannot access" << endl;
 	else
 	{
-		slog(SLOG_NOTICE) << "scheduler started" << endl;
+		slog(SLOG_NOTICE) << "scheduler: started" << endl;
 		interval = Load();
 		Update();
 	}
@@ -88,7 +88,7 @@ void Scheduler::Initial(void)
 
 void Scheduler::Stop(void)
 {
-	slog(SLOG_DEBUG) << "scheduler stopped" << endl;
+	slog(SLOG_DEBUG) << "scheduler: stopped" << endl;
 	Terminate();
 	sched.close();
 	close(rtmp);
@@ -107,6 +107,7 @@ void Scheduler::Run(void)
 		else
 			Sleep(60000);
 
+		Session::Clean();
 		time(&now);
 		sync = Sync::first;
 		while(sync)
@@ -169,7 +170,7 @@ int Scheduler::Load(void)
 	int hr, min;
 	int lhr = 24, lmin = 0;
 	int id, t1, t2, td;
-	char *sp;
+	char *sp = lbuf;
 	struct tm tbuf;
 
 	time(&now);
@@ -177,25 +178,21 @@ int Scheduler::Load(void)
 
 	if(!sched.is_open())
 	{
-		WriteLock();
 		group = TrunkGroup::first;
 		while(group)
 		{
 			group->setSchedule(NULL);
 			group = group->next;
 		}
-		Unlock();
 		return keythreads.getInterval();
 	}
-		
+	
 	sched.seekg(0);
 	sched.clear();
 
-	WriteLock();
 	for(;;)
 	{
 		sched.getline(lbuf, 255);
-
 		if(sched.eof())  
 			break;
 	
@@ -210,7 +207,7 @@ int Scheduler::Load(void)
 		day = strtok_r(NULL, " \t\n", &sp);
 		start = strtok_r(NULL, " \t\n", &sp);
 		cp = strtok_r(NULL, " \t\n", &sp);
-		if(!cp || !day || ! start)
+		if(!cp || !day || !start)
 		{
 			slog(SLOG_ERROR) << "error in schedule" << endl;
 			continue;
@@ -226,7 +223,8 @@ int Scheduler::Load(void)
 			hr = atoi(start);
 			min = atoi(strchr(start, ':') + 1);	
 		}			
-	
+
+
 		if(hr < lhr || (hr == lhr && min < lmin))
 			if(hr > dt->tm_hour || (hr == dt->tm_hour && min >= dt->tm_min))
 			{
@@ -236,11 +234,11 @@ int Scheduler::Load(void)
 
 		if(hr > dt->tm_hour || (hr == dt->tm_hour && min > dt->tm_min))
 			continue;
-		
+
 		if(!strcmp(name, "*"))
 		{
 			if ( !( group = TrunkGroup::first ) ) 
-				slog( SLOG_WARNING ) << "scheduler could not find any group" << endl;
+				slog( SLOG_WARNING ) << "scheduler: could not find any groups" << endl;
 			while(group)
 			{
 				group->setSchedule(cp);
@@ -255,7 +253,7 @@ int Scheduler::Load(void)
 			group = keyserver.getGroup(p);
 			if(!group) 
 			{ 
-				slog( SLOG_WARNING ) << "unknown group '" << p << "' refereced in schedule" << endl;
+				slog( SLOG_WARNING ) << "scheduler::unknown group '" << p << "' refereced in schedule" << endl;
 				continue;
 			} 
 			else
@@ -263,7 +261,6 @@ int Scheduler::Load(void)
 			p = strtok_r(NULL, ",;", &sp);
 		}
 	}
-	Unlock();
 
 	sched.clear(); // Probably we've hit an EOF - so we must clear fail()
 
