@@ -45,6 +45,10 @@
 #include <getopt.h>
 #include <sys/wait.h>
 
+#ifdef	_POSIX_MEMLOCK
+#include <sys/mman.h>
+#endif
+
 int tgipipe[2];
 static int *tgipids = NULL;
 static int mainpid;
@@ -60,6 +64,40 @@ static setenv(char *name, const char *value, int overwrite)
 }
 #endif
 
+static void rt(void)
+{
+	int min, max;
+	int pages = keythreads.getPages();
+	int pri = keythreads.getPriority();
+	int policy = keythreads.getPolicy();
+	char memory[1024 * pages];
+
+#ifdef	_POSIX_PRIORITY_SCHEDULING
+	struct sched_param p;
+	
+	sched_getparam(0, &p);
+	pri += p.sched_priority;
+	if(!policy)
+		policy = sched_getscheduler(0);
+
+	min = sched_get_priority_min(policy);
+	max = sched_get_priority_max(policy);
+	if(pri < min)
+		pri = min;
+	if(pri > max)
+		pri = max;
+	p.sched_priority = pri;
+	sched_setscheduler(getpid(), policy, &p); 
+#else
+	nice(-pri);
+#endif
+
+#ifdef	MCI_CURRENT
+	if(pages)
+		mlockall(MCI_CURRENT | MCI_FUTURE);
+#endif
+}
+
 static void tgi(void)
 {
 	int argc;
@@ -70,6 +108,8 @@ static void tgi(void)
 	tgipids = new int[count];
 	sigset_t sigs;
 	tgicmd_t cmd;
+	TGI *tgi;
+	int status;
 
 	if(canModify(keypaths.getRunfiles()))
 	{
@@ -116,15 +156,31 @@ static void tgi(void)
 	{
 		argc = 0;
 		slog(SLOG_DEBUG) << "tgi: cmd=" << cmd.cmd << endl;
+		tgi = getInterp(cmd.cmd);
+		if(tgi)
+		{
+			if(!cmd.detach)
+				sprintf(buffer, "wait %d %d\n", cmd.port, getpid());
+			status = tgi->Parse(cfd, cmd.port, cmd.cmd);
+			if(!cmd.detach)
+				sprintf(buffer, "exit %d %d\n", cmd.port, status);
+			continue;
+		}
 		vpid = vfork();
 		if(vpid)
 		{
-			sprintf(buffer, "wait %d %d\n", cmd.port, vpid);
-			write(cfd, buffer, strlen(buffer));
+			if(!cmd.detach)
+			{
+				sprintf(buffer, "wait %d %d\n", cmd.port, vpid);
+				write(cfd, buffer, strlen(buffer));
+			}
 
 			waitpid(vpid, &stat, 0);
-			sprintf(buffer, "exit %d %d", cmd.port, WEXITSTATUS(stat));
-			write(cfd, buffer, strlen(buffer));
+			if(!cmd.detach)
+			{
+				sprintf(buffer, "exit %d %d", cmd.port, WEXITSTATUS(stat));
+				write(cfd, buffer, strlen(buffer));
+			}
 			continue;
 		}
 
@@ -182,6 +238,7 @@ static void tgi(void)
 
 		setenv("PATH", getenv("SERVER_LIBEXEC"), 1);
 		sprintf(buffer, "%s/%s", getenv("SERVER_LIBEXEC"), *argv);
+		getInterp(buffer, argv);
 		execvp(buffer, argv);
 		slog(SLOG_ERROR) << "tgi: exec failed; " << buffer << endl;
 		exit(-1);
@@ -374,8 +431,19 @@ static void initial(int argc, char **argv)
 	slog() << "; driver=" << plugins.getDriverName();
 	slog() << "; prefix=" << prefix << endl;
 
+	slog(SLOG_DEBUG) << "Loading TGI plugins..." << endl;
+	try
+	{
+		plugins.loadTGI();
+	}
+	catch(DSO *dso)
+	{
+		slog(SLOG_CRITICAL) << dso->getError() << endl;
+		final(-1);
+	}
 	tgi();
 	sleep(1);
+	rt();
 
 	try
 	{
@@ -384,6 +452,7 @@ static void initial(int argc, char **argv)
 			plugins.loadExtensions();
 		plugins.loadDebug();
 		plugins.loadDriver();
+		plugins.loadModules();
 		plugins.loadDatabase();
 		plugins.loadFunctions();
 		plugins.loadTranslators();
@@ -418,6 +487,11 @@ static void initial(int argc, char **argv)
 		slog(SLOG_CRITICAL) << "protocol resolver failed" << endl;
 		final(-1);
 	}
+	catch(Thread *)
+	{
+		slog(SLOG_CRITICAL) << "service failure" << endl;
+		final(-1);
+	}
 	catch(...)
 	{
 		slog(SLOG_CRITICAL) << "unknown failure" << endl;
