@@ -48,7 +48,8 @@
 typedef	struct
 {
 	unsigned short port;
-	char cmd[254];
+	bool detach;
+	char cmd[256 - sizeof(short) - sizeof(bool)];
 } tgicmd_t;
 
 typedef	struct
@@ -96,31 +97,5 @@ public:
 	Resolver();
 };
 
-// this is a common base class for protocol configuration entries and is
-// used to support the optional resolver thread.
-
-class Protocol : public Keydata, public InetHostAddress, public ThreadLock
-{
-private:
-	friend class Resolver;
-	static Protocol *first;
-	Protocol *next;
-	Semaphore *sessions;
-	short port;
-
-	void Update(InetHostAddress &addr);
-public:
-	Protocol(const char *keypath, short port);
-	~Protocol();
-
-	InetHostAddress getAddress(void);
-
-	inline short getPort(void)
-		{return port;};
-	
-	inline Semaphore *getSessions(void)
-		{return sessions;};
-};
-
 extern Scheduler scheduler;
 extern int tgipipe[2];
