@@ -210,10 +210,22 @@ bool Trunk::Attach(const char *name)
 	struct tm *dt;
 	struct tm tbuf;
 
-	if(flags.script)
-		return false;
+	// This concerns me.  Why are we returning false?
+	// What, in fact, is this case?
 
-	flags.reset = flags.dtmf = flags.offhook = false;
+	// Since we just set TRUNK_MODE_OUTGOING, in our parent
+	// stack frame, I'll kill the flags.script case if we
+	// are outbound scheduled.
+
+	//Matt B
+
+	if(flags.trunk != TRUNK_MODE_OUTGOING) 
+	{
+	    if(flags.script)
+	        return false;
+	}
+
+	flags.reset = flags.dtmf = flags.offhook = flags.once = false;
 	tgi.pid = 0;
 
 	if(manager)
@@ -274,6 +286,9 @@ bool Trunk::Attach(const char *name)
 	if(!start)
 		time(&start);
 
+	if(database)
+		database->Initialize(this);
+
 	debug->DebugState(this, "attach script");
 	return true;
 }
@@ -318,6 +333,8 @@ void Trunk::Detach(void)
 	if(tgi.pid)
 		kill(tgi.pid, SIGHUP);
 	tgi.pid = 0;
+	if(database)
+		database->Finalize(this);
 	debug->DebugState(this, "detach script");
 }
 
